## Another Geodata Library for Input/Output (aglio :garlic:)

**aglio** focuses on data aggregation and regularization from a variety of sources, with an emphasis on geophysical applications but may be useful beyond. 

For now, check out the examples [here]() for an idea of what you can do! 

## Installation

For a base installation: 

```shell
pip install aglio
```

To install optional dependencies: 

```shell
pip install aglio[full]
```

To install extra dependencies that are not used by `aglio` but **are** used in 
some of the examples:

```shell
pip install aglio[extra]
```

## Development installation 

after forking and cloning: 

```shell
pip install -e .[dev]
```